@@ -535,14 +535,10 @@ class Model:
             key_indexes = SEP.join([self.__class__._serie_name(),
                                     __class__._S_INDEXES, ''])
 
-        key_count = 0
-        change_count = 0
-
         allvars = vars(self)
         for name in allvars:
             if name.startswith('_'): continue
 
-            key_count += 1
             value = allvars[name]
 
             if self._id >= 0 and hasattr(self.__class__, name) and \
@@ -562,14 +558,11 @@ class Model:
             _type = type(value)
             if _type == dict:
                 pipe.hmset(name, value)
-                change_count += 1
             elif _type == set:
                 pipe.sadd(name, *value)
-                change_count += 1
             elif _type == list:
                 pipe.delete(name)
                 pipe.rpush(name, *value)
-                change_count += 1
             elif _type == datetime.datetime:
                 pipe.hmset(name, {
                            __class__._S_YEAR: value.year,
@@ -582,13 +575,11 @@ class Model:
                 if value.tzinfo:
                     pipe.hset(name, __class__._S_UTC_OFFSET,
                               int(value.tzinfo.utcoffset(None).total_seconds()))
-                change_count += 1
             elif _type == datetime.date:
                 pipe.hmset(name, {
                            __class__._S_YEAR: value.year,
                            __class__._S_MONTH: value.month,
                            __class__._S_DAY: value.day })
-                change_count += 1
             elif _type == datetime.time:
                 pipe.hmset(name, {
                            __class__._S_HOUR: value.hour,
@@ -598,24 +589,14 @@ class Model:
                 if value.tzinfo:
                     pipe.hset(name, __class__._S_UTC_OFFSET,
                               int(value.tzinfo.utcoffset(None).total_seconds()))
-                change_count += 1
             elif value != None:
                 pipe.set(name, value)
-                change_count += 1
             else:
                 pipe.delete(name)
-                change_count -= 1
             #.for
 
         pipe.execute()
-
-        # ADD OR REMOVE _id to ID SET
-
-        if key_count + change_count == 0:
-            self.__class__._remove_id(self._id)
-            self._id = -1
-        else:
-            self.__class__._add_id(self._id)
+        self.__class__._add_id(self._id)
         #.put()
 
     def delete(self):
